==> limonaid_0.1.1.tar.gz: limonaid/README.md <==

<!-- badges: start -->

[![Pipeline
status](https://gitlab.com/r-packages/limonaid/badges/prod/pipeline.svg)](https://gitlab.com/r-packages/limonaid/-/commits/prod)
[![Coverage
status](https://codecov.io/gl/r-packages/limonaid/branch/prod/graph/badge.svg)](https://app.codecov.io/gl/r-packages/limonaid?branch=prod)
[![Version on
CRAN](https://www.r-pkg.org/badges/version/limonaid?color=brightgreen)](https://cran.r-project.org/package=limonaid)
[![Version on
CRAN](https://cranlogs.r-pkg.org/badges/last-month/limonaid?color=brightgreen)](https://cran.r-project.org/package=limonaid)
[![Version on
CRAN](https://cranlogs.r-pkg.org/badges/grand-total/limonaid?color=brightgreen)](https://cran.r-project.org/package=limonaid)
<!-- badges: end -->

# <img src='img/hex-logo.png' align="right" height="200" /> limonaid 📦

limonaid: Working With LimeSurvey Surveys and Responses

The pkgdown website for this project is located at
<https://r-packages.gitlab.io/limonaid>.

<!--------------------------------------------->
<!-- Start of a custom bit for every package -->
<!--------------------------------------------->

LimeSurvey is Free/Libre Open Source Software for the development and
administrations of online studies, using sophisticated tailoring
capabilities to support multiple study designs. This package supports
programmatic creation of surveys that can then be imported into
LimeSurvey, as well as userfriendly import of responses from LimeSurvey
studies.

<!--------------------------------------------->
<!--  End of a custom bit for every package  -->
<!--------------------------------------------->

## Installation

You can install the released version of `limonaid` from
[CRAN](https://CRAN.R-project.org) with:

``` r
install.packages('limonaid');
```

You can install the development version of `limonaid` from
[GitLab](https://about.gitlab.com) with:

``` r
remotes::install_gitlab('r-packages/limonaid');
```

(assuming you have `remotes` installed; otherwise, install that first
using the `install.packages` function)

==> limonaid_0.1.3.tar.gz: limonaid/README.md <==

<!-- badges: start -->

[![Pipeline
status](https://gitlab.com/r-packages/limonaid/badges/prod/pipeline.svg)](https://gitlab.com/r-packages/limonaid/-/commits/prod)
[![Coverage
status](https://codecov.io/gl/r-packages/limonaid/branch/prod/graph/badge.svg)](https://app.codecov.io/gl/r-packages/limonaid?branch=prod)
[![Version on
CRAN](https://www.r-pkg.org/badges/version/limonaid?color=brightgreen)](https://cran.r-project.org/package=limonaid)
[![Version on
CRAN](https://cranlogs.r-pkg.org/badges/last-month/limonaid?color=brightgreen)](https://cran.r-project.org/package=limonaid)
[![Version on
CRAN](https://cranlogs.r-pkg.org/badges/grand-total/limonaid?color=brightgreen)](https://cran.r-project.org/package=limonaid)
<!-- badges: end -->

# <img src='img/hex-logo.png' align="right" height="200" /> limonaid 📦

limonaid: Working With LimeSurvey Surveys and Responses

The pkgdown website for this project is located at
<https://r-packages.gitlab.io/limonaid>.

<!--------------------------------------------->
<!-- Start of a custom bit for every package -->
<!--------------------------------------------->

LimeSurvey is Free/Libre Open Source Software for the development and
administrations of online studies, using sophisticated tailoring
capabilities to support multiple study designs. This package supports
programmatic creation of surveys that can then be imported into
LimeSurvey, as well as userfriendly import of responses from LimeSurvey
studies. {limonaid} also implements a number of functions to work with
the LimeSurvey API from the defunct {limer} package by [Andrew
Heiss](https://www.andrewheiss.com).

<!--------------------------------------------->
<!--  End of a custom bit for every package  -->
<!--------------------------------------------->

## Installation

You can install the released version of `limonaid` from
[CRAN](https://CRAN.R-project.org) with:

``` r
install.packages('limonaid');
```

You can install the development version of `limonaid` from
[GitLab](https://about.gitlab.com) with:

``` r
remotes::install_gitlab('r-packages/limonaid');
```

(assuming you have `remotes` installed; otherwise, install that first
using the `install.packages` function)
